pycdf.const - Constants from the CDF library — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »

# pycdf.const - Constants from the CDF library

Various constants defined in cdf.h and used in pycdf. Most constants referred to in the CDF manuals are provided by this module. E.g., to create a CDF and add a variable of type EPOCH:

    >>> from spacepy import pycdf
    >>> cdf = pycdf.CDF('new.cdf', '')
    >>> cdf.new('epoch', type=pycdf.const.CDF_EPOCH)

Copyright 2010-2012 Los Alamos National Security, LLC.

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »